HEADER_KEYS_ALIASES = (
    'tracl', 'trace_record', 'fldr', 'tracf', 'ep', 'cdp', 'cdpt', 'trid',
    'nvs', 'nhs', 'duse', 'offset', 'gelev', 'selev', 'sdepth', 'gdel',
    'sdel', 'swdep', 'gwdep', 'scalel', 'scalco', 'sx', 'sy', 'gx',
    'gy', 'counit', 'wevel', 'swevel', 'sut', 'gut', 'sstat', 'gstat',
    'tstat', 'laga', 'lagb', 'delrt', 'muts', 'mute', 'ns', 'dt',
    'gain', 'igc', 'igi', 'corr', 'sfs', 'sfe', 'slen', 'styp', 'stas',
    'stae', 'tatyp', 'afilf', 'afils', 'nofilf', 'nofils', 'lcf',
    'hcf', 'lcs', 'hcs', 'year', 'day', 'hour', 'minute', 'sec',
    'timbas', 'trwf', 'grnors', 'grnofr', 'grnlof', 'gaps', 'otrav',
    'd1', 'f1', 'd2', 'f2', 'ungpow', 'unscale'
)